@@ -13,8 +13,8 @@
 # limitations under the License.
 import invoke
 
-from . import deploy
 from . import release
+from . import static
 
 
-ns = invoke.Collection(deploy, release)
+ns = invoke.Collection(release, static)
